@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -15,9 +13,17 @@
 
 
 """
-Root module definitions.
+Buildarr root module.
 """
 
 
-# Static version declaration.
-__version__ = "0.1.0"
+from __future__ import annotations
+
+from importlib_metadata import PackageNotFoundError, version as package_version
+
+__all__ = ["__version__"]
+
+try:
+    __version__: str = package_version("buildarr")
+except PackageNotFoundError:
+    __version__ = "0.1.0"
