@@ -13,7 +13,7 @@
 
 
 """
-'buildarr daemon' CLI command.
+`buildarr daemon` CLI command.
 """
 
 
@@ -23,21 +23,23 @@ import itertools
 import signal
 
 from datetime import datetime, time
+from logging import getLogger
 from pathlib import Path
 from time import sleep
 from typing import TYPE_CHECKING, cast
 
 import click
 
-from importlib_metadata import version as package_version
 from schedule import Job as SchedulerJob, Scheduler  # type: ignore[import]
-from watchdog.events import FileSystemEventHandler  # type: ignore[import]
-from watchdog.observers import Observer  # type: ignore[import]
+from watchdog.events import FileSystemEventHandler
+from watchdog.observers import Observer
 
-from ..config import load as load_config
-from ..logging import logger
+from .. import __version__
+from ..config import load_config
+from ..logging import get_log_level
 from ..state import state
 from ..types import DayOfWeek
+from ..util import get_absolute_path
 from . import cli
 from .run import _run as run_apply
 
@@ -45,7 +47,10 @@ if TYPE_CHECKING:
     from types import FrameType
     from typing import Dict, Iterable, List, Optional, Set, Tuple, Union
 
-    from watchdog.events import DirModifiedEvent, FileModifiedEvent  # type: ignore[import]
+    from watchdog.events import DirModifiedEvent, FileModifiedEvent
+
+
+logger = getLogger(__name__)
 
 
 class Daemon:
@@ -59,6 +64,7 @@ class Daemon:
     def __init__(
         self,
         config_path: Path,
+        secrets_file_path: Optional[Path],
         watch_config: Optional[bool],
         update_days: Iterable[DayOfWeek],
         update_times: Iterable[time],
@@ -77,6 +83,7 @@ class Daemon:
         """
         # Set static configuration and override field values.
         self.config_path = config_path
+        self._default_secrets_file_path = secrets_file_path
         self._default_watch_config = watch_config
         self._default_update_days = set(update_days)
         self._default_update_times = set(update_times)
@@ -94,10 +101,17 @@ class Daemon:
         Load the Buildarr configuration from the given file, and set daemon configuration fields.
         """
         # Load the Buildarr configuration, and save the list of files loaded.
+        logger.info("Loading configuration file '%s'", self.config_path)
         load_config(self.config_path)
+        logger.info("Finished loading configuration file")
         # Set watch_config, update_days and update_times from either the
         # command line-provided override value or the value from the configuration.
         buildarr_config = state.config.buildarr
+        self.secrets_file_path = (
+            self._default_secrets_file_path
+            if self._default_secrets_file_path
+            else buildarr_config.secrets_file_path
+        )
         self.watch_config = (
             self._default_watch_config
             if self._default_watch_config is not None
@@ -171,7 +185,7 @@ class Daemon:
             logger.info("   - %s %s", update_day.name.capitalize(), update_time.strftime("%H:%M"))
         # Apply initial configuration to all defined remote instances.
         logger.info("Applying initial configuration")
-        run_apply()
+        run_apply(secrets_file_path=self.secrets_file_path)
         logger.info("Finished applying initial configuration")
         # Schedule configuration update jobs according to the configuration,
         # so that remote instances are automatically updated periodically.
@@ -197,7 +211,9 @@ class Daemon:
         # and another initial run is performed.
         if self.watch_config:
             logger.info("Setting up config file monitoring")
-            self.observer = Observer()
+            # TODO: Remove ignore when the following issue is fixed.
+            # https://github.com/gorakhargosh/watchdog/issues/982
+            self.observer = Observer()  # type: ignore[assignment]
             config_dirs: Dict[Path, Set[str]] = {}
             for config_file in state.config_files:
                 if config_file.parent not in config_dirs:
@@ -224,7 +240,7 @@ class Daemon:
         This method is called by the scheduled automatic update jobs.
         """
         logger.info("Running scheduled update of remote instances")
-        run_apply()
+        run_apply(secrets_file_path=self.secrets_file_path)
         state._reset()
         logger.info("Finished running scheduled update of remote instances")
         logger.info(
@@ -360,10 +376,32 @@ def parse_time(
         file_okay=True,
         dir_okay=False,
         readable=True,
-        resolve_path=True,
         path_type=Path,
     ),
     default=Path.cwd() / "buildarr.yml",
+    # Get absolute path, but do NOT resolve symlinks in daemon mode.
+    callback=lambda ctx, params, path: get_absolute_path(path),
+)
+@click.option(
+    "-s",
+    "--secrets-file",
+    "secrets_file_path",
+    metavar="SECRETS-JSON",
+    type=click.Path(
+        # The secrets file does not need to exist (it will be created in that case).
+        file_okay=True,
+        dir_okay=False,
+        readable=True,
+        path_type=Path,
+    ),
+    default=None,
+    # Get absolute path, but do NOT resolve symlinks in daemon mode.
+    callback=lambda ctx, params, path: get_absolute_path(path) if path else None,
+    help=(
+        "Read secrets metadata from (and write back to) the specified JSON file. "
+        "If unspecified, use the value from the configuration file, "
+        "and if undefined there, default to `secrets.json'."
+    ),
 )
 @click.option(
     "-w/-W",
@@ -405,12 +443,13 @@ def parse_time(
 )
 def daemon(
     config_path: Path,
+    secrets_file_path: Optional[Path],
     watch_config: Optional[bool],
     update_days: Tuple[DayOfWeek, ...],
     update_times: Tuple[time, ...],
 ) -> None:
     """
-    'buildarr daemon' command main routine.
+    `buildarr daemon` command main routine.
 
     Args:
         config_path (Path): Buildarr configuration file to load
@@ -419,14 +458,11 @@ def daemon(
         update_times (Tuple[time, ...]): Override `update_times` setting
     """
 
-    logger.info(
-        "Buildarr version %s (log level: %s)",
-        package_version("buildarr"),
-        logger.log_level,
-    )
+    logger.info("Buildarr version %s (log level: %s)", __version__, get_log_level())
 
     Daemon(
         config_path=config_path,
+        secrets_file_path=secrets_file_path,
         watch_config=watch_config,
         update_days=update_days,
         update_times=update_times,
