@@ -24,8 +24,10 @@ from __future__ import annotations
 from ..plugins import load as load_plugins
 from ..state import state
 from . import cli as main
-from .daemon import daemon  # noqa: F401
-from .run import run  # noqa: F401
+from .compose import compose
+from .daemon import daemon
+from .run import run
+from .test_config import test_config
 
 __all__ = ["main"]
 
@@ -35,7 +37,8 @@ load_plugins()
 
 # Load CLI modules for all installed plugins.
 for plugin_name, plugin in state.plugins.items():
-    main.add_command(plugin.cli, name=plugin_name)
+    if plugin.cli is not None:
+        main.add_command(plugin.cli, name=plugin_name)
 
 if __name__ == "__main__":
     main()
