@@ -19,13 +19,15 @@ Buildarr settings configuration.
 
 from __future__ import annotations
 
+import os
+
 from datetime import time
 from pathlib import Path
 from typing import Set
 
 from pydantic import AnyHttpUrl, PositiveFloat
 
-from ..types import DayOfWeek
+from ..types import DayOfWeek, LocalPath, NonEmptyStr
 from .base import ConfigBase
 
 
@@ -114,10 +116,21 @@ class BuildarrConfig(ConfigBase):
     This configuration option can be overridden using the `--update-times` command line argument.
     """
 
-    # TODO: Make this relative to the configuration file, not local to the current directory.
-    secrets_file_path: Path = Path("secrets.json")
+    secrets_file_path: LocalPath = LocalPath("secrets.json")
     """
     Path to store the Buildarr instance secrets file.
+
+    By default, this will create a file called `secrets.json` in the same folder
+    the first loaded configuration file is located.
+
+    *New in version 0.4.0*: This configuration option can now be overridden
+    using the `--secrets-file` command line argument.
+
+    *Changed in version 0.4.0*: Relative file paths are now evaluated relative
+    to the directory the configuration file that defined the attribute is located,
+    not the current working directory of the Buildarr process. If the attribute
+    is undefined, the secrets file will be created in the directory the
+    originally loaded configuration file is located.
     """
 
     request_timeout: PositiveFloat = 30  # seconds
@@ -126,7 +139,7 @@ class BuildarrConfig(ConfigBase):
 
     If the timeout is reached, an error will occur and Buildarr will stop the update process.
 
-    *Added in version 0.3.0.*
+    *New in version 0.3.0.*
     """
 
     trash_metadata_download_url: AnyHttpUrl = (
@@ -140,3 +153,19 @@ class BuildarrConfig(ConfigBase):
     """
     Metadata directory name within the downloaded ZIP file.
     """
+
+    docker_image_uri: NonEmptyStr = os.environ.get(  # type: ignore[assignment]
+        "BUILDARR_DOCKER_IMAGE_URI",
+        "callum027/buildarr",
+    )
+    """
+    Default image URI to use for the Buildarr service when generating Docker Compose files.
+
+    If undefined in the configuration file, use the value defined in the
+    `$BUILDARR_DOCKER_IMAGE_URI` environment variable. This allows third-party
+    Docker images to customise the version of Buildarr used in the command.
+
+    If no environment variable is found, use `callum027/buildarr` (the official Docker image).
+
+    *New in version 0.4.0.*
+    """
