@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -19,6 +17,9 @@ Buildarr exception classes.
 """
 
 
+from __future__ import annotations
+
+
 class BuildarrError(Exception):
     """
     Buildarr exception base class.
