@@ -19,10 +19,18 @@ Buildarr manager interface.
 
 from __future__ import annotations
 
-from pathlib import Path
-from typing import Generic
+from logging import getLogger
+from typing import TYPE_CHECKING, Generic
 
 from ..plugins import Config, Secrets
+from ..state import state
+
+if TYPE_CHECKING:
+    from pathlib import Path
+    from typing import Any, Dict, Optional, Set
+
+
+logger = getLogger(__name__)
 
 
 class ManagerPlugin(Generic[Config, Secrets]):
@@ -74,7 +82,7 @@ class ManagerPlugin(Generic[Config, Secrets]):
         Returns whether or not the given instance configuration uses TRaSH-Guides metadata.
 
         Args:
-            config (Config): Configuration object to check
+            instance_config (Config): Instance configuration object to check.
 
         Returns:
             `True` if TRaSH-Guides metadata is used, otherwise `False`
@@ -87,7 +95,7 @@ class ManagerPlugin(Generic[Config, Secrets]):
         with all templates rendered.
 
         Args:
-            config (Config): Configuration object to read.
+            instance_config (Config): Instance configuration object to render.
             trash_metadata_dir (Path): TRaSH-Guides metadata directory.
 
         Returns:
@@ -97,10 +105,10 @@ class ManagerPlugin(Generic[Config, Secrets]):
 
     def from_remote(self, instance_config: Config, secrets: Secrets) -> Config:
         """
-        Get the remote instance configuration for this section, and return the resulting object.
+        Get the active configuration for a remote instance, and return the resulting object.
 
         Args:
-            config (Config): Configuration object to read.
+            instance_config (Config): Configuration object of the instance to connect to.
             secrets (Secrets): Remote instance host and secrets information.
 
         Returns:
@@ -132,3 +140,48 @@ class ManagerPlugin(Generic[Config, Secrets]):
             secrets=secrets,
             remote=remote_instance_config,
         )
+
+    def to_compose_service(
+        self,
+        instance_config: Config,
+        compose_version: str,
+        service_name: str,
+    ) -> Dict[str, Any]:
+        """
+        Generate a Docker Compose service definition corresponding to this instance configuration.
+
+        Args:
+            instance_config (Config): Instance configuration to generate a service for.
+            compose_version (str): Version of the Docker Compose file.
+            service_name (str): The unique name for the generated Docker Compose service.
+
+        Returns:
+            Docker Compose service definition dictionary
+        """
+        return instance_config.to_compose_service(
+            compose_version=compose_version,
+            service_name=service_name,
+        )
+
+
+def load_managers(use_plugins: Optional[Set[str]] = None) -> None:
+    """
+    Load the managers for each plugin to be used in this Buildarr run.
+
+    Args:
+        use_plugins (Optional[Set[str]]): Plugins to use. Default is to use all plugins.
+    """
+
+    managers: Dict[str, ManagerPlugin] = {}
+
+    for plugin_name, plugin in state.plugins.items():
+        if use_plugins and plugin_name not in use_plugins:
+            continue
+        if plugin_name not in state.config.__fields_set__:
+            continue
+        with state._with_context(plugin_name=plugin_name):
+            logger.debug("Loading plugin manager")
+            managers[plugin_name] = plugin.manager()
+            logger.debug("Finished loading plugin manager")
+
+    state.managers = managers
