@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (C) 2023 Callum Dickinson
 #
 # Buildarr is free software: you can redistribute it and/or modify it under the terms of the
@@ -21,9 +19,8 @@ Buildarr plugin specification.
 
 from __future__ import annotations
 
-from .context import plugin_context
 from .load import load
 from .models import Plugin
 from .types import Config, Secrets
 
-__all__ = ["Config", "Secrets", "Plugin", "load", "plugin_context"]
+__all__ = ["Plugin", "Config", "Secrets", "load"]
