@@ -35,9 +35,10 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Mapping, cast
 
 from flask import Flask, Response, jsonify, request
-from importlib_metadata import version as package_version
 from werkzeug.exceptions import Unauthorized
 
+from buildarr import __version__
+
 if TYPE_CHECKING:
     from typing import Any, Dict, Tuple
 
@@ -111,11 +112,30 @@ def get_initialize_js() -> Tuple[str, int]:
     res = f"window.Dummy = {{\n  apiRoot: {repr(app.config['API_ROOT'])}"
     if "API_KEY" in app.config and app.config["API_KEY"]:
         res += f",\n  apiKey: {repr(app.config['API_KEY'])}"
-    res += f",\n  version: {repr(package_version('buildarr'))}\n}};"
+    res += f",\n  version: {repr(__version__)}\n}};"
 
     return (res, 200)
 
 
+@app.get(f"{app.config['API_ROOT']}/status")
+def get_status() -> Tuple[Response, int]:
+    """
+    Return the Dummy server current status.
+
+     ```bash
+    $ curl -H "X-Api-Key: 1a2b3c4d5e" http://localhost:5000/api/v1/status
+    {"version":"0.4.0"}
+    ```
+
+    Returns:
+        Dummy server status
+    """
+
+    check_api_key()
+
+    return (jsonify({"version": __version__}), 200)
+
+
 @app.get(f"{app.config['API_ROOT']}/settings")
 def get_settings() -> Tuple[Response, int]:
     """
