@@ -19,11 +19,11 @@ Buildarr plugin loading functions.
 
 from __future__ import annotations
 
+from logging import getLogger
 from typing import TYPE_CHECKING
 
 from stevedore.extension import ExtensionManager  # type: ignore[import]
 
-from ..logging import logger
 from ..state import state
 
 if TYPE_CHECKING:
@@ -34,6 +34,9 @@ if TYPE_CHECKING:
     from . import Plugin
 
 
+logger = getLogger(__name__)
+
+
 def load(namespace: str = "buildarr.plugins") -> None:
     """
     Load plugins from the given namespace.
