@@ -24,15 +24,16 @@ import os
 from collections import defaultdict
 from contextlib import contextmanager
 from distutils.util import strtobool
+from pathlib import Path
 from typing import TYPE_CHECKING, Tuple
 
 if TYPE_CHECKING:
-    from pathlib import Path
-    from typing import DefaultDict, Generator, Mapping, Optional, Sequence, Set
+    from typing import DefaultDict, FrozenSet, Generator, Mapping, Optional, Sequence, Set
 
-    from .config import ConfigType
+    from .config import ConfigPlugin, ConfigType
+    from .manager import ManagerPlugin
     from .plugins import Plugin
-    from .secrets import SecretsType
+    from .secrets import SecretsPlugin, SecretsType
 
 
 __all__ = ["state"]
@@ -58,16 +59,21 @@ class State:
     Whether Buildarr is in testing mode or not.
     """
 
+    dry_run: bool = False
+    """
+    Whether Buildarr is in dry run mode or not.
+
+    When set to `True` under a CLI command that supports it, the command should not
+    perform any action that would change the state of any external instances.
+
+    Custom CLI commands can set this attribute to `True` if they support a dry-run mode.
+    """
+
     plugins: Mapping[str, Plugin] = {}
     """
     The loaded Buildarr plugins, mapped to the plugin's unique name.
     """
 
-    config_files: Sequence[Path] = []
-    """
-    Currently loaded configuration files, in the order they were loaded.
-    """
-
     config: ConfigType = None  # type: ignore[assignment]
     """
     Currently loaded global configuration.
@@ -75,11 +81,38 @@ class State:
     This includes Buildarr configuration and configuration for enabled plugins.
     """
 
+    config_files: Sequence[Path] = []
+    """
+    Currently loaded configuration files, in the order they were loaded.
+    """
+
+    managers: Mapping[str, ManagerPlugin[ConfigPlugin, SecretsPlugin]]
+    """
+    Manager objects for each currently loaded plugin.
+    """
+
+    instance_configs: Mapping[str, Mapping[str, ConfigPlugin]]
+    """
+    Fully qualified configuration objects for each instance, under each plugin.
+    """
+
+    active_plugins: FrozenSet[str]
+    """
+    A data structure containing the names of all the currently active plugins.
+    """
+
     secrets: SecretsType
     """
     Currently loaded instance secrets.
     """
 
+    _current_dir: Path = Path.cwd()
+    """
+    Current working directory for relative path resolution.
+
+    This state attribute is internal, and shouldn't be accessed by plugins.
+    """
+
     _current_plugin: str
     """
     The plugin being processed in the current context.
@@ -107,6 +140,17 @@ class State:
     This state attribute is internal, and shouldn't be accessed by plugins.
     """
 
+    _execution_order: Sequence[PluginInstanceRef]
+    """
+    A list of plugin-instance references in the order which operations
+    should be performed on them.
+
+    This attribute is generated based on the dependency tree for linked instances,
+    after `state._instance_dependencies` has finished being populated.
+
+    This state attribute is internal, and shouldn't be accessed by plugins.
+    """
+
     def __init__(self) -> None:
         self._reset()
 
@@ -118,10 +162,29 @@ class State:
 
         This state function is internal, and shouldn't be used by plugins.
         """
+        self.managers = None  # type: ignore[assignment]
+        self.instance_configs = None  # type: ignore[assignment]
+        self.active_plugins = None  # type: ignore[assignment]
         self.secrets = None  # type: ignore[assignment]
         self._current_plugin = None  # type: ignore[assignment]
         self._current_instance = None  # type: ignore[assignment]
         self._instance_dependencies = defaultdict(set)  # type: ignore[assignment]
+        self._execution_order = None  # type: ignore[assignment]
+
+    @contextmanager
+    def _with_current_dir(self, current_dir: Path) -> Generator[None, None, None]:
+        """
+        Set the current directory context within a code block.
+
+        This state function is internal, and shouldn't be used by plugins.
+
+        Args:
+            current_dir (Path): Path to use as the current directory.
+        """
+        old_current_dir = self._current_dir
+        self._current_dir = current_dir
+        yield
+        self._current_dir = old_current_dir
 
     @contextmanager
     def _with_context(
